TaeraeGraphReranker class abstract interface

Hook interface for re-ranking retrieval hits.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rerank(String query, List<TaeraeGraphRagHit> hits) Future<List<TaeraeGraphRagHit>>
Re-orders or rescored hits for query.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited